==> camel-k-crds-2.0.1-sources.jar: org/apache/camel/v1alpha1/kameletbindingspec/steps/Types.java <==
package org.apache.camel.v1alpha1.kameletbindingspec.steps;

@com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
@com.fasterxml.jackson.annotation.JsonPropertyOrder({"mediaType","schema"})
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@javax.annotation.processing.Generated("io.fabric8.java.generator.CRGeneratorRunner")
public class Types implements io.fabric8.kubernetes.api.model.KubernetesResource {

    /**
     * media type as expected for HTTP media types (ie, application/json)
     */
    @com.fasterxml.jackson.annotation.JsonProperty("mediaType")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("media type as expected for HTTP media types (ie, application/json)")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private String mediaType;

    public String getMediaType() {
        return mediaType;
    }

    public void setMediaType(String mediaType) {
        this.mediaType = mediaType;
    }

    /**
     * the expected schema for the event
     */
    @com.fasterxml.jackson.annotation.JsonProperty("schema")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("the expected schema for the event")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private org.apache.camel.v1alpha1.kameletbindingspec.steps.types.Schema schema;

    public org.apache.camel.v1alpha1.kameletbindingspec.steps.types.Schema getSchema() {
        return schema;
    }

    public void setSchema(org.apache.camel.v1alpha1.kameletbindingspec.steps.types.Schema schema) {
        this.schema = schema;
    }
}

==> camel-k-crds-2.3.3-sources.jar: org/apache/camel/v1alpha1/kameletbindingspec/steps/Types.java <==
package org.apache.camel.v1alpha1.kameletbindingspec.steps;

@com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
@com.fasterxml.jackson.annotation.JsonPropertyOrder({"mediaType","schema"})
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@javax.annotation.processing.Generated("io.fabric8.java.generator.CRGeneratorRunner")
@lombok.ToString()
@lombok.EqualsAndHashCode()
@io.sundr.builder.annotations.Buildable(editableEnabled = false, validationEnabled = false, generateBuilderPackage = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.ObjectMeta.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.ObjectReference.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.LabelSelector.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.Container.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.EnvVar.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.ContainerPort.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.Volume.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.VolumeMount.class)
})
public class Types implements io.fabric8.kubernetes.api.model.KubernetesResource {

    /**
     * media type as expected for HTTP media types (ie, application/json)
     */
    @com.fasterxml.jackson.annotation.JsonProperty("mediaType")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("media type as expected for HTTP media types (ie, application/json)")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private String mediaType;

    public String getMediaType() {
        return mediaType;
    }

    public void setMediaType(String mediaType) {
        this.mediaType = mediaType;
    }

    /**
     * the expected schema for the event
     */
    @com.fasterxml.jackson.annotation.JsonProperty("schema")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("the expected schema for the event")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private org.apache.camel.v1alpha1.kameletbindingspec.steps.types.Schema schema;

    public org.apache.camel.v1alpha1.kameletbindingspec.steps.types.Schema getSchema() {
        return schema;
    }

    public void setSchema(org.apache.camel.v1alpha1.kameletbindingspec.steps.types.Schema schema) {
        this.schema = schema;
    }
}
